
import setuptools
import os

class uploader:
    def __init__(self) -> None:
        pass
    
    name_=None
    version_=None
    license_=None
    author_=None
    author_email_=None
    description_=None
    long_description_=None
    url_=None
    classifiers_=None
    
    def up(self) :           
        print("package name=")
        self.name_=input()
        print("virsion=")
        self.version_=input()
        print("license=")
        self.license_=input()
        print("author=")
        self.author_=input()
        print("author_email=")
        self.author_email_=input()
        print("description=")
        self.description_=input()
        print("long_description=open('README.md').read()")
        self.long_description_='README.md'
        print("url=")
        self.url_=input()
        print("packages=setuptools.find_packages()")
        print("")
        input()
        print("classifiers")
        self.classifiers_=""



    def load(self) :
        os.system('pip freeze > requirements.txt')
        strings=f'import setuptools\nsetuptools.setup(name="{self.name_}",version="{self.version_}",license="{self.license_}",author="{self.author_}",author_email="{self.author_email_}",description="{self.description_}",long_description=open(\'README.md\').read(),url="{self.url_}",packages=setuptools.find_packages(),classifiers=["Programming Language :: Python :: 3","License :: OSI Approved :: MIT License","Operating System :: OS Independent"],)'
        f=open('setup.py','w')
        f.write(strings)
        f.close()
        f=open('__init__.py','w')
        f.close()
    


import sys
import os
from upload import uploader 



if __name__=="__main__":
    
    file_path=sys.argv[1]



    if sys.argv[1]=='twine':
        os.system('python setup.py sdist bdist_wheel')
        os.system('python -m twine upload dist/*')
    else : 
        if len(sys.argv)!=2:
            print("Insufficient arguments")
            sys.exit()

        f=open("README.md",'w')
        f.close()
        f=open("setup.py",'w')
        f.close()
        f=open("LICENSE",'w')
        f.close()
            
        print("note the follows")

        upload_1=uploader()
        upload_1.up()
        upload_1.load()
        

        os.system('python setup.py sdist bdist_wheel')


import setuptools
setuptools.setup(name="pkmg",version="2.0.7",license="MIT",author="DaeHyeonGo",author_email="castar2001kr@naver.com",description="pkmg",long_description=open('README.md').read(),url="https://github.com/castar2001kr/python.pkmg.git",packages=setuptools.find_packages(),classifiers=["Programming Language :: Python :: 3","License :: OSI Approved :: MIT License","Operating System :: OS Independent"],)